==> jc-1.4.0.tar.gz: java/awt/geom/GeneralPath__24GeneralPathIterator.h <==
// class java.awt.geom.GeneralPath$GeneralPathIterator

// class file dependencies
// @dep_class 80f599e69e91507f java_awt_geom_GeneralPath__24GeneralPathIterator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_GeneralPath__24GeneralPathIterator_H_
#define _JC_java_awt_geom_GeneralPath__24GeneralPathIterator_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_GeneralPath$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object;

typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct;
typedef const struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods;
typedef const struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable;
typedef const struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype;

// Class fields structure
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct {
	_jc_int_array	*NUM__5fCOORDS;
};
extern _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$class_fields;

// Constructors
extern void _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$_init$537d01d66f4e0d19(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_java_awt_geom_GeneralPath$object *, struct _jc_java_awt_geom_AffineTransform$object *);

// Virtual methods
extern jint _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_double_array *);
extern jint _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_float_array *);
extern jint _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *);
extern jboolean _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *);
extern void _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$next$08839245f4046cfe;

// Static methods
extern void _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_double_array *);
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_float_array *);
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *);
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *);
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *);
};

// Vtable
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods	java_awt_geom_GeneralPath__24GeneralPathIterator;
};

// Vtype
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype {
	_jc_type			type;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs {
	struct _jc_java_awt_geom_GeneralPath$object	*path;
	struct _jc_java_awt_geom_AffineTransform$object	*transform;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs {
    _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs	java_awt_geom_GeneralPath__24GeneralPathIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs {
	jint	pos;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs	java_awt_geom_GeneralPath__24GeneralPathIterator;
};

// Object instance structure
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object {
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype	*vtype;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_GeneralPath__24GeneralPathIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$class_object;

#endif	/* _JC_java_awt_geom_GeneralPath__24GeneralPathIterator_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/GeneralPath__24GeneralPathIterator.h <==
// class java.awt.geom.GeneralPath$GeneralPathIterator

// class file dependencies
// @dep_class b0c27def2407d84f java_awt_geom_GeneralPath__24GeneralPathIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_GeneralPath__24GeneralPathIterator_H_
#define _JC_java_awt_geom_GeneralPath__24GeneralPathIterator_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_GeneralPath$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs;
typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object;

typedef struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct;
typedef const struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods;
typedef const struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable;
typedef const struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype;

// Class fields structure
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct {
	_jc_int_array	*NUM__5fCOORDS;
};
extern _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$fields_struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$class_fields;

// Constructors
extern void _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$_init$537d01d66f4e0d19(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_java_awt_geom_GeneralPath$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method_info$next$08839245f4046cfe;

// Static methods
extern void _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *) _JC_JCNI_ATTR;
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vmethods	java_awt_geom_GeneralPath__24GeneralPathIterator;
};

// Vtype
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype {
	_jc_type			type;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs {
	struct _jc_java_awt_geom_GeneralPath$object	*path;
	struct _jc_java_awt_geom_AffineTransform$object	*transform;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs {
    _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_refs	java_awt_geom_GeneralPath__24GeneralPathIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs {
	jint	pos;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$sub_nonrefs	java_awt_geom_GeneralPath__24GeneralPathIterator;
};

// Object instance structure
struct _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$object {
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype	*vtype;
	_jc_java_awt_geom_GeneralPath__24GeneralPathIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$vtype _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_GeneralPath__24GeneralPathIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_GeneralPath__24GeneralPathIterator$class_object;

#endif	/* _JC_java_awt_geom_GeneralPath__24GeneralPathIterator_H_ */
